@@ -9,9 +9,17 @@ from math import sqrt, ceil, floor
 
 from sklearn.cluster import KMeans
 
+import numpy as np
+import cv2
+
 from typing import Union
 from typing import Tuple
 
+import urllib.request
+import base64
+
+import operator
+
 logger = initial_logger()
 
 
@@ -171,6 +179,7 @@ def pad(
 
     return result
 
+
 def pad_unet(
     image: np.array,
     factor: int = 32,
@@ -210,6 +219,7 @@ def pad_unet(
 
     return padded_image, (x_min_pad, y_min_pad, x_max_pad, y_max_pad)
 
+
 def unpad_unet(image: np.array, pads: Tuple[int, int, int, int]) -> np.ndarray:
     """Crops patch from the center so that sides are equal to pads.
 
@@ -224,6 +234,8 @@ def unpad_unet(image: np.array, pads: Tuple[int, int, int, int]) -> np.ndarray:
     height, width = image.shape[:2]
 
     return image[y_min_pad: height - y_max_pad, x_min_pad: width - x_max_pad]
+
+
 def isBase64(sb):
     try:
         if isinstance(sb, str):
@@ -393,6 +405,7 @@ def np_to_base64(
     im_b64 = base64.b64encode(im_bytes)
     return im_b64.decode("utf-8")
 
+
 def load_rgb(
     image: np.array,
     lib: str = "cv2"
@@ -410,6 +423,7 @@ def load_rgb(
     image = cv2.cvtColor(image, cv2.COLOR_BGR2RGB)
     return image
 
+
 def resize(image, width=None, height=None, inter=cv2.INTER_AREA):
     # initialize the dimensions of the image to be resized and # grab the image size
     dim = None
@@ -440,6 +454,7 @@ def resize(image, width=None, height=None, inter=cv2.INTER_AREA):
     # return the resized image
     return resized
 
+
 def image_url_to_cv2_image(url):
     # download the image, convert it to a NumPy array, and then read
     # it into OpenCV format
@@ -518,7 +533,7 @@ def scaled_point(
 def get_scaled_points(
     intersections=None,
     orig_image=None,
-    processed_image = None
+    processed_image=None
 ):
     ratio = get_image_ratio(
         orig_image,
